@@ -32,7 +32,7 @@
 MOGL_Fenetre::MOGL_Fenetre(char * p_Titre):_ResolutionX(640), _ResolutionY(480), _NbBitParPixel(16), _FinBoucle(false),
                                            _Fullscreen(false),_GrabCurseur(false), 
                                            _RepetitionDelai(SDL_DEFAULT_REPEAT_DELAY), _RepetitionIntervalle(SDL_DEFAULT_REPEAT_INTERVAL),
-                                           _NumeroImage(0), _ExisteFenetre(false), _CacheSouris(true)
+                                           _NumeroImage(0), _ExisteFenetre(false), _CacheSouris(true), _bManualResize(false)
                                                                                    
 {
   if (p_Titre!=NULL)
@@ -107,7 +107,7 @@ bool MOGL_Fenetre::Initialiser()
   }
   else
   {
-    flags = SDL_OPENGL;// | SDL_RESIZABLE;
+    flags = SDL_OPENGL | SDL_RESIZABLE;
   }
 
   // On regarde si notre rsolution est bien disponible
@@ -324,7 +324,7 @@ bool MOGL_Fenetre::SetMode(int p_ResolutionX, int p_ResolutionY, bool p_Fullscre
   }
   else
   {
-    flags = SDL_OPENGL;// | SDL_RESIZABLE;
+    flags = SDL_OPENGL | SDL_RESIZABLE;
   }
 
   if (_ExisteFenetre)
@@ -434,6 +434,14 @@ void MOGL_Fenetre::SetFullscreen(bool p_Fullscreen)
     _Fullscreen=p_Fullscreen;
     if (_ExisteFenetre)
     {
+        if (_bManualResize)
+        {
+            _bManualResize = false;
+            _ResolutionX=_MemResolutionX;
+            _ResolutionY=_MemResolutionY;
+        }
+        SetMode(_ResolutionX, _ResolutionY, p_Fullscreen);
+#if 0
 #ifdef WIN32
       // Bien entendu, sous windows le changement de rsulotion n'est pas si simple que cela...
       // Au lieu de simplement appeler une petite fonction, il faut dtruire l'environnement video
@@ -442,6 +450,7 @@ void MOGL_Fenetre::SetFullscreen(bool p_Fullscreen)
       SetMode(_ResolutionX, _ResolutionY, p_Fullscreen);
 #else
       SDL_WM_ToggleFullScreen(_SurfaceSDL);
+#endif
 #endif
     }
   }
@@ -472,12 +481,95 @@ bool MOGL_Fenetre::_InitGL()
 
 // *************************
 
+void MOGL_Fenetre::_ManualResize(int p_ResolutionX, int p_ResolutionY)
+{
+    if (!_bManualResize)
+    {
+        _MemResolutionX=_ResolutionX;
+        _MemResolutionY=_ResolutionY;
+        _bManualResize = true;
+    }
+  _ResolutionX=p_ResolutionX;
+  _ResolutionY=p_ResolutionY;
+  _Fullscreen=false;
+  const SDL_VideoInfo* info;
+  int flags = 0;
+
+  flags = SDL_OPENGL | SDL_RESIZABLE;
+
+  if (_ExisteFenetre)
+  {
+#ifdef WIN32
+    // Sous windows le changement de rsolution semble trs allatoire...
+    // Du coup on va dire  SDL de terminer la gestion de la video
+    // (ce qui devrait dtruire la fentre), puis d'initialiser la video
+    // en recreant une fentre. Il semble que cela fonctionne mieux.
+
+    SDL_QuitSubSystem(SDL_INIT_VIDEO);
+    SDL_InitSubSystem(SDL_INIT_VIDEO);
+#endif
+
+    _SurfaceSDL = _CreerFenetre(_NbBitParPixel, flags);
+    
+    if (_SurfaceSDL == NULL)
+    {
+      // Erreur lors de la crtaion de la fentre
+      // On regarde si l'on est en 32 bits
+      if (_NbBitParPixel == 32)
+      {
+        // Il est possible que l'on soit en fait en 24 bit
+        // (SDL dit un peu n'importe quoi dans ce cas !)
+        // On recommence donc !
+        _NbBitParPixel = 24;
+        _SurfaceSDL = _CreerFenetre(_NbBitParPixel, flags);
+      }
+    }
+    if (_SurfaceSDL == NULL)
+    {
+        cerr<<"Manual resize error !"<<endl;
+    }
+
+#ifdef WIN32
+    SDL_WM_SetCaption(_Titre,NULL);
+#endif
+
+
+    _Reshape(_ResolutionX, _ResolutionY);
+  
+    info=SDL_GetVideoInfo();
+    //_NbBitParPixel=info->vfmt->BitsPerPixel;
+
+    if (_CacheSouris)
+    {
+      SDL_ShowCursor(0);
+    }
+    else
+    {
+      SDL_ShowCursor(1);
+    }
+
+    if (_GrabCurseur)
+    {
+      SDL_WM_GrabInput(SDL_GRAB_ON);
+    }
+    else
+    {
+      SDL_WM_GrabInput(SDL_GRAB_OFF);
+    }
+    SDL_EnableKeyRepeat(_RepetitionDelai, _RepetitionIntervalle);
+
+   
+    ChangementMode.Emettre(_ResolutionX, _ResolutionY, _NbBitParPixel);
+  }
+}
+
 void MOGL_Fenetre::_Reshape(int w, int h)
 {       
   glViewport (0, 0, (GLsizei) w, (GLsizei) h);
 
   _ResolutionX=w;
   _ResolutionY=h;
+
 /*
   glMatrixMode (GL_PROJECTION);
   glLoadIdentity();
@@ -533,7 +625,7 @@ void MOGL_Fenetre::_GestionEvenement()
         _FinBoucle=true;
         break;
       case SDL_VIDEORESIZE:
-        _Reshape(event.resize.w,event.resize.h);
+          _ManualResize(event.resize.w,event.resize.h);
         break;
     }
   }
