@@ -99,3 +99,15 @@ Uint16 * MOGL_Police::_AllocAndConvertToUCS2(string p_Chaine, unsigned int & siz
 
   return stToRet;
 }
+
+unsigned int MOGL_Police::_ReadUnsignedInt(ifstream & file)
+{
+    unsigned int val;
+    file.read((char *) &val, sizeof (val));
+#if SDL_BYTEORDER == SDL_LIL_ENDIAN
+    return val;
+#else
+    SDL_Swap32(val);
+    return val;
+#endif
+}
