@@ -248,7 +248,24 @@ unsigned int MOGL_PoliceTTF::GetTailleYCaractere(Uint16 p_Caractere) const
 
 bool MOGL_PoliceTTF::Recharger()
 {
-  return Charger(_NomFichier.c_str());
+    MOGL_Struct_TextureCarac texture;
+
+    for(MOGL_Vector_TextureName::iterator it=_VectorTextureName.begin(); it != _VectorTextureName.end(); it++)
+    {
+        texture = *it;
+        glBindTexture(GL_TEXTURE_2D,texture.TextureName);
+        if (_bOldOpenGl)
+        {
+            glTexImage2D(GL_TEXTURE_2D,0,GL_RGBA,TEXTURE_SIZE,TEXTURE_SIZE,0,GL_RGBA,GL_UNSIGNED_BYTE,texture.SurfaceSDL->pixels);
+        }
+        else
+        {
+            glTexImage2D(GL_TEXTURE_2D,0,GL_RGBA,TEXTURE_SIZE,TEXTURE_SIZE,0,GL_RGBA,GL_UNSIGNED_INT_8_8_8_8,texture.SurfaceSDL->pixels);
+        }
+        glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MIN_FILTER,GL_NEAREST);
+        glTexParameteri(GL_TEXTURE_2D,GL_TEXTURE_MAG_FILTER,GL_NEAREST);
+    }
+    return true;
 }
 
 MOGL_PoliceTTF::MOGL_Struct_Carac * MOGL_PoliceTTF::_GetCarac(Uint16 p_Carac)
